@@ -58,6 +58,7 @@
  * 03 Mar 06, daved@physiol.usyd.edu.au: fixed creation date spelling
 		and added support for accented characters in titles from
 		Laurent Monin
+ # 09 Mar 06, daved@physiol.usyd.edu.au: don't print null post_trans
  *--------------------------------------------------------------------*/
 
 #ifdef HAVE_CONFIG_H
@@ -2645,7 +2646,10 @@ enum { SMALL=0, BIG=1 };
 #else
 			post_trans = op_translate_char (op, charset_type, ch);
 #endif
-			printf("%s",post_trans);
+#if 1 /* daved - 0.20.1 */
+			if(post_trans)
+#endif
+				printf("%s",post_trans);
 		}
 
 		s++;
